References
==========

Options
--------
.. automodule:: sequana_pipetools.options
    :members:
    :undoc-members:


Sequana Manager
---------------

.. automodule:: sequana_pipetools.sequana_manager
    :members:
    :undoc-members:


FileFactory and FastQFactory
----------------------------
.. automodule:: sequana_pipetools.snaketools.file_factory
    :members:
    :undoc-members:


Pipeline manager
-----------------
.. automodule:: sequana_pipetools.snaketools.pipeline_manager
    :members:
    :undoc-members:
